pub struct TieredObjectStore { /* private fields */ }Expand description
Tiered object store composing a hot (memory) and cold (block) tier.
New objects are written to the hot tier. When the hot tier is full, the least recently used object is demoted to the cold tier. On a hot-tier miss, the cold tier is consulted and matching objects are promoted back to the hot tier.
Example
use grafos_store::{TieredObjectStore, ObjectStore, FabricUri};
let mut store = TieredObjectStore::new(32, 256, 16)?;
let uri: FabricUri = "fabric://p/b/k".parse()?;
store.put(&uri, b"data", None)?;
let obj = store.get(&uri)?.unwrap();
assert_eq!(obj.data, b"data");Implementations
Sourceimpl TieredObjectStore
impl TieredObjectStore
Sourcepub fn new(hot_buckets: usize, cold_blocks: u64, max_hot: usize) -> Result<Self>
pub fn new(hot_buckets: usize, cold_blocks: u64, max_hot: usize) -> Result<Self>
Create a tiered store.
hot_buckets: number of hash map buckets for the hot tiercold_blocks: number of blocks for the cold tiermax_hot: maximum objects in hot tier before LRU eviction
Sourcepub fn checkpoint(&self) -> Result<()>
pub fn checkpoint(&self) -> Result<()>
Checkpoint the cold tier index to block storage.
Sourceimpl TieredObjectStore
Mutable get with LRU tracking and cold-to-hot promotion.
impl TieredObjectStore
Mutable get with LRU tracking and cold-to-hot promotion.